# Python Package Exercise

## Badge

*include badge showing the result of the latest build/test workflow run.*

## Project Description

*write the project description here*

## Instructions

*write instructions here*

## Code Examples

` # code example for how a developer who wants to import your project into their own code can do so - include documentation for all functions in your package and a link to an example Python program that uses each of them.`

` # code example for how a developer who wants to contribute to your project can set up the virtual environment, install dependencies, and build and test your package for themselves.`


## Team Names

Nicolas Izurieta: https://github.com/ni2050


## Link to Package

*insert link to package's page on PyPi website here*

